<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2021 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Jun 16, 2021
 */

/**
 * @package InterWorx
 * @subpackage CLI
 */
class AcronisDbRestorer extends CLI
{
    const PARAM_DATABASES = 'databases';
    const PARAM_UNIXUSER = 'unixuser';
    const PARAM_BACKUP_ID = 'backup_id';
    const PARAM_RESTORE_ID = 'restore_id';

    const FUNCTION_RESTORE_SW = 'restoreSiteWorxDatabases';
    const FUNCTION_RESTORE_UNMAPPED = 'restoreUnmappedDatabases';

    /**
     * Register functions, install & uninstall.
     */
    public function registerOptArgs()
    {
        $this->_func(self::FUNCTION_RESTORE_SW, 'restore siteworx databases');
        $this->_func(self::FUNCTION_RESTORE_UNMAPPED, 'restore unmapped databases');

        $this->_param(self::PARAM_DATABASES . '=s', 'databases to restore');
        $this->_param(self::PARAM_UNIXUSER . '=s', 'unix user');
        $this->_param(self::PARAM_BACKUP_ID . '=s', 'databases to restore');
        $this->_param(self::PARAM_RESTORE_ID . '=s', 'restore id');
    }

    /**
     * Restore SiteWorx Databases.
     */
    protected function _restoreSiteWorxDatabases()
    {
        $this->_requires(self::FUNCTION_RESTORE_SW, self::PARAM_BACKUP_ID, self::PARAM_DATABASES, self::PARAM_UNIXUSER, self::PARAM_RESTORE_ID);

        $backupId = $this->_getOption(self::PARAM_BACKUP_ID);
        $dbsArg = $this->_getOption(self::PARAM_DATABASES);
        $unixUser = $this->_getOption(self::PARAM_UNIXUSER);
        $restoreId = $this->_getOption(self::PARAM_RESTORE_ID);

        try {
            $Restorer = new Model_Recovery_Files_Databases_Siteworx($backupId, $unixUser, $restoreId);
            $dbs = explode(',', $dbsArg);
            $Restorer->restoreDatabases($dbs);
            $this->success('successfully restored databases: ' . $dbsArg);
        } catch (Exception $e) {
            $this->_setRestoreStateToFailed($restoreId, $e->getMessage());
            $this->fail("Failed restoring databases: $dbsArg. " . $e->getMessage());
        }
    }

    /**
     * Update cache state to failed if not updated already.
     *
     * Most situations are handled & cached within db restore.
     * Adding here in case anything unexpected happens,
     * e.g. auth api throwing exception
     *
     * @param string $restoreId
     * @param string $errorMessage
     */
    private function _setRestoreStateToFailed($restoreId, $errorMessage)
    {
        $Cache = new Model_Cache_Restore_Databases();

        if ($Cache->exists($restoreId)) {
            $restore = $Cache->get($restoreId);
            $state = $restore[$Cache::STATE];

            if ($state !== $Cache::STATE_FAILED) {
                $Cache->setFailed($restoreId);
                $Cache->setErrorMsg($restoreId, $errorMessage);
            }
        }
    }

    /**
     * Restore NodeWorx Databases.
     */
    protected function _restoreUnmappedDatabases()
    {
        $this->_requires(self::FUNCTION_RESTORE_UNMAPPED, self::PARAM_BACKUP_ID, self::PARAM_DATABASES, self::PARAM_RESTORE_ID);

        $backupId = $this->_getOption(self::PARAM_BACKUP_ID);
        $dbsArg = $this->_getOption(self::PARAM_DATABASES);
        $restoreId = $this->_getOption(self::PARAM_RESTORE_ID);
        $dbs = explode(',', $dbsArg);

        try {
            $DbRestorer = new Model_Recovery_Files_Databases_Nodeworx($backupId, $restoreId);
            $DbRestorer->restoreUnmappedDatabases($dbs);

            $this->success("Databases successfully restored: $dbsArg");
        } catch (Exception $e) {
            $this->_setRestoreStateToFailed($restoreId, $e->getMessage());
            $this->fail("Failed restoring databases: $dbsArg. " . $e->getMessage());
        }
    }
}
