<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2021 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Aug 05, 2021
 */

/**
 * @package InterWorx
 * @subpackage
 */
class Model_AcronisFileSys
{

    /**
     * Create directory as root.
     *
     * @param string $path
     */
    public static function createDir($path)
    {
        if (!self::isDir($path)) {
            $mkdirCommand = "mkdir -p $path && chmod 0755 $path";
            $Command = new Command($mkdirCommand);
            $Command->allowAmpersand();
            $Command->runAsRoot();
            $Command->exec();

            if (!$Command->wasSuccessful()) {
                throw new Exception('could not create dir: ' . $path);
            }
        }
    }

    /**
     * Check if dir - runs as root.
     *
     * @param string $path
     */
    public static function isDir($path)
    {
        $Command = new Command("[[ -d $path ]]");
        $Command->runAsRoot();
        $Command->allowBracketBoth();

        return $Command->exec();
    }

    /**
     * check if file exists.
     *
     * @param string $path
     * @return boolean
     */
    public static function isFile($path)
    {
        $Command = new Command("[[ -f $path ]]");
        $Command->runAsRoot();
        $Command->allowBracketBoth();

        return $Command->exec();
    }

    /**
     * @param string $path
     * @return array
     */
    public static function getDirContent($path)
    {
        $Command = new Command("ls -a $path");
        $Command->runAsRoot();
        $Command->exec();

        if (!$Command->wasSuccessful()) {
            throw new Exception_Acronis_InvalidPath($path);
        }

        $content = $Command->getOutput();
        return self::_excludeParents($content);
    }

    /**
     * @param array $content
     * @return array
     */
    private static function _excludeParents(array $content)
    {
        $filtered = array_filter($content, function ($dir) {
            return $dir !== '.' && $dir !== '..';
        });

        return array_values($filtered);
    }

    /**
     * @param string $unixuser
     * @param string $dbName
     * @return string
     */
    public static function getDatabaseDumpsPath($unixuser, $dbName)
    {
        return self::getUserDumpsPath($unixuser) . "/$dbName";
    }

    /**
     * @param string $unixuser
     * @return string
     */
    public static function getUserDumpsPath($unixuser)
    {
        return Model_Recovery_Files_Databases::DUMPS_TEMP_PATH . "/$unixuser-dumps";
    }

    /**
     * @param string $path
     */
    public static function rm($path)
    {
        $Command = new Command("rm -rf $path");
        $Command->runAsRoot();
        $Command->exec();

        if (!$Command->wasSuccessful()) {
            throw new Exception('unable to delete ' . $path);
        }
    }
}
