<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2021 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Aug 30, 2021
 */
require_once(__DIR__ . '/../../Nodeworx.php');
/**
 * @package InterWorx
 * @subpackage
 */
class NwDirContentTest extends Acronis_NodeworxTest
{
    /**
     * Test getRootContent. Tests successful reply and that payload is not empty.
     */
    public function testGetRootContent()
    {
        echo __FUNCTION__;

        // backups are sorted by date - new backup will be first item in array
        $backup = $this->_getBackups()[0];
        $Backup = new Model_Backups_Backup($backup);

        $Reply = $this->_sendCtrlRequest('getRootContent', array(
            'ab_backup_id' => $Backup->getBackupId()
        ));

        $this->assertReplySuccessful($Reply);
        $this->assertNotEmpty($Reply->getPayloadData());
    }


    /**
     * Test list directories. Should include all content, not just first 200.
     */
    public function testListDirectories()
    {
        echo __FUNCTION__;

        // backups are sorted by date - new backup will be first item in array
        $backup = $this->_getBackups()[0];
        $Backup = new Model_Backups_Backup($backup);

        $Reply = $this->_sendCtrlRequest('getDirectoryContent', array(
           'ab_backup_id' => $Backup->getBackupId(),
           'ab_directory_path' => self::PARENT_DIR_PATH_TEST
        ));

        $dirContent = $Reply->getPayloadData();
        $this->assertCount(self::DIR_CONTENT_EXPECTED_COUNT, $dirContent);
    }
}
