<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2021 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Sep 15, 2021
 */
require_once(__DIR__ . '/../../Nodeworx.php');
/**
 * @package InterWorx
 * @subpackage
 */
class NwUnmappedPrescriptDataTest extends Acronis_NodeworxTest
{
    const UNMAPPED_DIRNAME = 'UNMAPPED';

    /**
     * test listUnmappedPrescriptData
     */
    public function testListUnmappedPrescriptData()
    {
        $this->_createPrescriptData();
        $payloadData = $this->_getUnmappedPrescriptData();
        $unmapped = array_shift($payloadData);

        $this->assertArrayHasKey('databases_mapped', $unmapped);
        $this->assertArrayHasKey('databases_unmapped', $unmapped);
        $this->assertArrayHasKey('sw_users', $unmapped);
        $this->assertArrayHasKey('timestamp', $unmapped);
        $this->assertArrayHasKey('date', $unmapped);
        $this->assertArrayHasKey(Model_Cache_Abstract::DUMPS_DIR_UNMAPPED, $unmapped);

        $this->assertSame(self::UNMAPPED_DIRNAME, $unmapped[Model_Cache_Abstract::DUMPS_DIR_UNMAPPED]);
    }

    /**
     * Create prescript data.
     */
    private function _createPrescriptData()
    {
        $cachePreBackupData = "/home/interworx/bin/php /home/interworx/plugins/acronis/bin/prebackup.php --cacheServerInfo --unmapped_dir=" . self::UNMAPPED_DIRNAME;
        Model_AcronisUtil::exec($cachePreBackupData);
    }

    /**
     * @return array
     */
    private function _getUnmappedPrescriptData()
    {
        $Reply = $this->_sendCtrlRequest('listUnmappedPrescriptData');
        $this->assertReplySuccessful($Reply);
        $prescripts = $Reply->getPayloadData();

        return $prescripts;
    }

    /**
     * test cleanupUnmappedPrescriptData
     */
    public function testCleanupUnmappedPrescriptData()
    {
        $this->_createPrescriptData();
        $prescriptsPreCleanup = $this->_getUnmappedPrescriptData();
        $this->assertNotEmpty($prescriptsPreCleanup);

        $this->_sendCtrlRequest('cleanupUnmappedPrescriptData');

        $prescriptsPostCleanup = $this->_getUnmappedPrescriptData();
        $this->assertEmpty($prescriptsPostCleanup);
    }
}
