<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2021 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Sep 20, 2021
 */
require_once(__DIR__ . '/../../Siteworx.php');
/**
 * @package InterWorx
 * @subpackage
 */
class SwRestoreToAltLocationTest extends Acronis_SiteworxTest
{
    /**
     * Delete temp location before test.
     */
    public function setUp()
    {
        $temp = $this->_getDefaultUserTempLocation();

        if (Model_AcronisFileSys::isDir($temp)) {
            Model_AcronisFileSys::rm($temp);
        }
    }

    /**
     * remove initiated flag if set.
     */
    public function tearDown()
    {
        $this->_deleteFlagInitiatedIfExists();
    }

    /**
     * test restoreToAltLocation
     */
    public function testRestoreToAltLocation()
    {
        echo __FUNCTION__;

        $user = self::ACRONISTESTUSER;
        $restore = $this->_getRelativePathDomain($user);

        $absolutePath = $this->_getSwAbsolutePath($user, $restore);
        $expectedContent = Model_AcronisFileSys::getDirContent($absolutePath);

        $this->_restoreToAltLocation($user, $restore);
        $this->_assertFilesRestoredToTemp($expectedContent);
    }

    /**
     * @param string $user
     * @param string $path
     */
    private function _restoreToAltLocation($user, $path)
    {
        $Reply = $this->_restoreToAlt($user, $path);
        $this->assertReplySuccessful($Reply);

        $payloadData = $Reply->getPayloadData();
        $planId = $payloadData['planId'];
        $this->_awaitRestore($planId);
    }

    /**
     * test restoreToAltLocation should fail when initiated flag is set.
     */
    public function testRestoreToAltLocationShouldFailWhileInitiated()
    {
        echo __FUNCTION__;

        $user = self::ACRONISTESTUSER;
        $restore = $this->_getRelativePathDomain($user);

        $this->_setInitiated();

        $Reply = $this->_restoreToAlt($user, $restore);
        $this->assertReplyNotSuccessful($Reply, 'expected action to fail while initiated flag is set');
        $this->_assertReplyReturnsRestoreInProgress($Reply);

        $this->_clearInitiated();
    }

    /**
     * @param string $user
     */
    private function _getRelativePathDomain($user)
    {
        return "$user.com";
    }

    /**
     * @param string $user
     * @param string $path
     * @return Reply
     */
    private function _restoreToAlt($user, $path)
    {
        $backupId = $this->_getLatestSwBackup($user)->getBackupId();
        $paths = array($path);

        $args = array(
            Form_AcronisBackups::INPUT_BACKUP_ID => $backupId,
            Form_AcronisBackups::INPUT_MULTI_DIR => $paths
        );

        return $this->_sendCtrlRequest('restoreToAltLocation', $args, $user);
    }

    /**
     * Compare content of restored files with actual content.
     *
     * @param array $expectedContent
     */
    private function _assertFilesRestoredToTemp(array $expectedContent)
    {
        $tempLocation = $this->_getDefaultUserTempLocation();
        $pathRecoveredFolder = $this->_getRestoredPath($tempLocation);

        $actualContent = Model_AcronisFileSys::getDirContent($pathRecoveredFolder);
        $this->assertSame($expectedContent, $actualContent);
    }

    /**
     * Get default user temp location.
     *
     * @return string
     */
    private function _getDefaultUserTempLocation()
    {
        $SW = $this->_getSw();
        return $SW->getPackageRoot() . "/acronis_temp";
    }
}
